
function [beta, lambda] = betas_binary(I,alpha)
% beta ... embedding change probs (vector of size of I)
% I ... Fisher info (vector)
% alpha ... payload in nats (scalar)
% NOTE: this function solves a system of equations I * lambda = 1/beta * log(1/beta - 1)

payload = alpha*numel(I);     % Absolute payload in nats

L = 10^3;                     % Initial search interval for lambda
R = L;

load('ixlnx2.mat')   % Loads two variables into the workspace: xx and yy (lookup tables of size 118)

fL = sum(h_bin(invxlnx2_fast(L*I,xx,yy))) - payload;
fR = sum(h_bin(invxlnx2_fast(R*I,xx,yy))) - payload;

while fL*fR > 0             % If the range [L,R] does not cover alpha,
    if fL > 0
        L = R;
        R = 2*R;
        fR = sum(h_bin(invxlnx2_fast(R*I,xx,yy))) - payload;
    else
        R = L;
        L = L/2;
        fL = sum(h_bin(invxlnx2_fast(L*I,xx,yy))) - payload;
    end
end

% ffM = [];
while abs(L-R) > 0.000001*(L+R)/2
    M = (L+R)/2;
    fM = sum(h_bin(invxlnx2_fast(M*I,xx,yy))) - payload;
%     ffM = [ffM fM];
%     figure(1); plot(ffM); drawnow();
    if fL*fM < 0
        R = M;
        fR = fM;
    else
        L = M;
        fL = fM;
    end
end

lambda = (L+R)/2;
beta = invxlnx2_fast(lambda*I,xx,yy);
