
function b = compute_ixlnx2(y)
% Solves y = z*log(z-1) for z
% z iz 1/beta and is in [0, 0.5]

L = 0.5;                     % Initial search interval for z (1/beta)
R = 10000;

fL = y - L*log(L-1);
fR = y - R*log(R-1);

while fL*fR > 0              % If the range [L,R] does not cover alpha,
    if fL > 0, R = 2*R;      % enlarge the search interval
    else       L = L/2; end
    fL = y - L*log(L-1);
    fR = y - R*log(R-1);
end

while abs(L-R) > 0.000000001*(L+R)/2
    M = (L+R)/2;
    fM = y - M*log(M-1);
    if fL*fM < 0, R = M; fR = fM;
    else          L = M; fL = fM; end
end
b = 2/(L+R);    % Solution in terms of beta (b), which is 1/z = b

% ***** Code for generating ixlnx.mat *****

% ind = 0;
% a = 1.2;                            % Base for geometric sampling
% f = log(2)/log(a);
% Range = -ceil(20*f):ceil(10*f);     % Geometric spacing to save on file size (spans from 2^-20 to 2^10)
% for j = Range
%     ind = ind + 1;
%     x(ind) = a^j;
%     z(ind) = compute_ixlnx2(x(ind));
% end
% xx(1) = 0; yy(1) = 0.5;
% xx(2:numel(Range)+1) = x;
% yy(2:numel(Range)+1) = z;
% save('ixlnx2.mat','xx','yy')
